# !/usr/bin/env python 
# -*- coding: utf-8 -*-
# file_name: constant_.py
# author: ScCcWe
# time: 2022/3/5 9:32 上午
MODULE_NAME = "PyMySQLDao"
FALSE_VALUE_LIST = [None, "", 0j, [], (), {}]
